@@ -1,7 +1,20 @@
 #!/bin/sh
+
+# Copyright (C) since 2006 NTT DATA Corporation
+# 
+# This program is free software; you can redistribute it and/or
+# Modify it under the terms of the GNU General Public License
+# as published by the Free Software Foundation, version 2.
+# 
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details
+
+# bash configuration
 RPM_PROC="/bin/rpm -Uvh"
 FTP_PROC="/usr/kerberos/bin/ftp"
-FTP_HOST="%%hinemos_ftp_host%%"
+FTP_HOST=%%FTP_HOST%%
 FTP_USER="hinemos"
 FTP_PASSWD="hinemos"
 RM_PROC="/bin/rm -f"
